Installation — copepodTCR 0.5.1 documentation

# Installation

1. Install copepodTCR.

   > With pip:

   >     pip install copepodTCR

   > Or with conda:

   >     conda install -c vasilisa.kovaleva copepodTCR

2. Instal dependencies for 3D modeling of masks. You can skip this step, if you don’t plan to use function from 3D model section.

   > After installing copepodTCR either way, install manifold3d:

   >     pip install manifold3d

   > Alternative to manifold3d is Blender, it can be installed from Blender official website (version 4.5 and higher).

   > You can use `cpp.pick_engine()` to check with engines are available in you environment.

## Requirements

Except for manifold3d, required packages should be installed simulataneously with the copepodTCR packages.

But if they were not, here is the list of requirements:

- pandas>=1.5.3

  >     pip install "pandas>=1.5.3"

- numpy>=1.23.5

  >     pip install "numpy>=1.23.5"

- trimesh>=3.23.5

  >     pip install "trimesh>=3.23.5"

- PyMC>=5.9.2

  >     pip install "pymc>=5.9.2"

- Arviz>=5.9.2

  >     pip install "arviz>=0.16.1"

- matplotlib>=3.10.5

  >     pip install "matplotlib>=3.10.5"

- seaborn>=0.13.2

  >     pip install "seaborn>=0.13.2"

- plotly>=6.2.0

  >     pip install "plotly>=0.13.2"